﻿
using System.Data.Entity;
using System.Net.Http;
using System.Net.Http.Formatting;
using System.Threading;
using AngularAspNetMvc.DataAccess;
using AngularAspNetMvc.Models.Core;
using AngularAspNetMvc.Tests.Core;
using AngularAspNetMvc.WebApi.Contacts;
using AutoMapper;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Newtonsoft.Json;
using AngularAspNetMvc.Models.Contacts;

namespace AngularAspNetMvc.Tests.Controllers
{
    [TestClass]
    public class ContactTypeControllerTests : ApiTest
    {
        [TestMethod]
        public void Insert_Should_Add_Contact_Via_Route()
        {
            ContactType contactType = null;
            using (var client = PrepareServer())
            {
                using (var request = new HttpRequestMessage(HttpMethod.Post, "http://localhost/api/contacttypes/save"))
                {

                    AddAuthorizationCookie("me@you.com", new { Prop1 = "1", Prop2 = "2" }, request);
                    var type = new ContactType
                    {
                        Name = "Test Type"
                    };
                    request.Content = new ObjectContent(typeof(ContactType), type, new JsonMediaTypeFormatter());
                    using (HttpResponseMessage response = client.SendAsync(request, CancellationToken.None).Result)
                    {

                        var content = response.Content.ReadAsStringAsync().Result;
                        var result = JsonConvert.DeserializeObject<ApiResult<ContactType>>(content);
                        Assert.IsTrue(result.Success, "Should successfully execute");
                        Assert.IsTrue(result.Result.ContactTypeId > 0, "Should have generated id");
                        contactType = result.Result;
                        Assert.AreEqual(type.Name, result.Result.Name, "Should have correct name");
                    }
                }
            }

            if (contactType != null)
            {
                using (var context = new ContactsContext())
                {
                    var entity = Mapper.Map<Data.Models.ContactType>(contactType);
                    context.Entry(entity).State = EntityState.Deleted;
                    context.SaveChanges();
                }
            }
        }

        [TestMethod]
        public void Insert_Should_Add_Contact()
        {
            var contactType = new ContactType
            {
                Name = "Test Type"
            };

            var controller = GetInstance<ContactTypesController>();
            var result = controller.Save(contactType);
            Assert.IsTrue(result.Success, "Should successfully execute");
            Assert.IsTrue(result.Result.ContactTypeId > 0, "Should have generated id");
            contactType = result.Result;
            Assert.AreEqual(contactType.Name, result.Result.Name, "Should have correct name");

            if (contactType != null)
            {
                using (var context = new ContactsContext())
                {
                    var entity = Mapper.Map<Data.Models.ContactType>(contactType);
                    context.Entry(entity).State = EntityState.Deleted;
                    context.SaveChanges();
                }
            }
        }



    }


}
