
module app.contacts {

    import IUtilities = app.core.services.IUtilities;
    import IHttp = app.core.services.http.IHttp;
    import IHttpResult = app.core.services.http.IHttpResult;
    import IContactType = app.contactTypes.models.IContactType;

    export interface IContactTypesScope extends app.core.controllers.ICoreScope {
        contactTypes: IContactType[];
        editType: (contactType: IContactType) => void;
        deleteType: (contactType: IContactType) => void;
        add: () => void;
    }

    export class ContactsTypesController extends app.core.controllers.CoreController {

        constructor(
            private utilities: IUtilities,
            private $scope: IContactTypesScope,
            $location: ng.ILocationService,
            contactsTypeService: app.contactTypes.services.IContactsTypeService) {
            super($scope);

            var getData = () => {
                contactsTypeService.getContactTypes((result: IContactType[]) => {
                    $scope.contactTypes = result;
                });
            };

            var deleteType = (contactType: app.contactTypes.models.IContactType) => {
                contactsTypeService.deleteContactType(contactType, (result: boolean) => {
                    if (result) {
                        getData();
                    }
                });
            };


            getData();

            $scope.editType = (contactType: app.contactTypes.models.IContactType) => {
                $location.path("/contacttype/edit/" + contactType.ContactTypeId);
            };

            $scope.add = () => {
                $location.path("/contacttype/edit/add");
            };

            $scope.deleteType = (contactType: app.contactTypes.models.IContactType) => {
                var buttons: app.core.services.IButtonForMessage[] = [
                    {
                        mehtod: () => {
                            deleteType(contactType);
                        },
                        label: "Delete"
                    },
                    {
                        label: "Cancel"
                    }
                ];
                utilities.showMessage("Delete type " + contactType.Name + "?", false, buttons);
            };


        }

    }

    angular.module("app.contacts.contactsTypesController",
        ["app.core.services.utilities", "app.core.services.http", "app.contactTypes.services"])
        .controller("app.contacts.contactsTypesController", ["utilities", "$scope", "$location", "contactsTypeService",
            function (
                utilities: IUtilities,
                $scope: IContactTypesScope,
                $location: ng.ILocationService,
                contactsTypeService: app.contactTypes.services.IContactsTypeService) {
                return new ContactsTypesController(utilities, $scope, $location, contactsTypeService);
            }]);
}