/// <reference path="../../../scripts/typings/angularjs/angular.d.ts" />
/// <reference path="../../../app/home/interfaces.ts" />
/// <reference path="../../../scripts/typings/angularjs/angular-mocks.d.ts" />
describe("Contact Types Controller", function () {
    var controller;
    var scope;
    var utilities;
    var $location;
    var contactsTypeService;
    var backEnd;

    beforeEach(function () {
        angular.mock.module("app.core.services.utilities");
        angular.mock.module("app.core.services.http");
        angular.mock.module("app.globalsModule");
        angular.mock.module("app.contactTypes.services");
    });

    beforeEach(inject(function ($rootScope, _$location_, _utilities_, _contactsTypeService_, $httpBackend, globalsService) {
        scope = $rootScope.$new();
        $location = _$location_;
        utilities = _utilities_;
        contactsTypeService = _contactsTypeService_;
        backEnd = $httpBackend;
        backEnd.when("GET", globalsService.webApiBaseUrl + "/ContactTypes/Get").respond({
            "Success": true,
            "ErrorMessage": "",
            "Result": [
                { "ContactTypeId": 2, "Name": "Coworker" },
                { "ContactTypeId": 3, "Name": "Family" },
                { "ContactTypeId": 5, "Name": "Fresh" },
                { "ContactTypeId": 1, "Name": "Friend" }
            ]
        });
        backEnd.when("POST", globalsService.webApiBaseUrl + "/ContactTypes/Delete", { "ContactTypeId": 2, "Name": "Coworker" }).respond({
            "Success": true,
            "ErrorMessage": "",
            "Result": { "ContactTypeId": 2, "Name": "Coworker" }
        });
    }));

    it("should create controller", function () {
        controller = new app.contacts.ContactsTypesController(utilities, scope, $location, contactsTypeService);
        expect(controller).not.toBeNull();
        expect(typeof scope.editType).toBe("function");
        expect(typeof scope.deleteType).toBe("function");
    });

    it("should have data", function () {
        controller = new app.contacts.ContactsTypesController(utilities, scope, $location, contactsTypeService);
        backEnd.flush();
        expect(scope.contactTypes).toBeDefined();
        expect(scope.contactTypes).not.toBeNull();
    });

    it("should have correct number of rows", function () {
        controller = new app.contacts.ContactsTypesController(utilities, scope, $location, contactsTypeService);
        backEnd.flush();
        expect(scope.contactTypes.length).toBe(4);
    });

    it("should change location on edit", function () {
        controller = new app.contacts.ContactsTypesController(utilities, scope, $location, contactsTypeService);
        backEnd.flush();
        expect(scope.contactTypes.length).toBe(4);
        scope.editType(scope.contactTypes[0]);
        expect($location.path()).toBe("/contacttype/edit/" + scope.contactTypes[0].ContactTypeId);
    });

    it("should change location on add", function () {
        controller = new app.contacts.ContactsTypesController(utilities, scope, $location, contactsTypeService);
        backEnd.flush();
        expect(scope.contactTypes.length).toBe(4);
        scope.add();
        expect($location.path()).toBe("/contacttype/edit/add");
    });

    it("should delete type", function () {
        controller = new app.contacts.ContactsTypesController(utilities, scope, $location, contactsTypeService);
        backEnd.flush();
        expect(scope.contactTypes.length).toBe(4);
        scope.deleteType(scope.contactTypes[0]);
        var deleteButton = $("#globalMessageDialog button").first();
        deleteButton.trigger("click");
        backEnd.flush();
        backEnd.verifyNoOutstandingExpectation();
        backEnd.verifyNoOutstandingRequest();
    });
});
//# sourceMappingURL=contactsTypesController.spec.js.map
